#
# spec file for package libqt5-qtquickcontrols2
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Internal QML imports of examples
%global __requires_exclude qmlimport\\((Backend|Theme|.*example).*

%define qt5_snapshot 1
%define base_name libqt5
%define real_version 5.15.16
%define so_version 5.15.16
%define tar_version qtquickcontrols2-everywhere-src-%{version}
Name:           libqt5-qtquickcontrols2
Version:        5.15.16+kde5
Release:        1.2
Summary:        Qt 5 Quick Controls Addon
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
URL:            https://www.qt.io
Source:         %{tar_version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  libQt5Core-private-headers-devel >= %{real_version}
BuildRequires:  libQt5Gui-private-headers-devel >= %{real_version}
BuildRequires:  libqt5-qtbase-devel >= %{real_version}
BuildRequires:  libqt5-qtdeclarative-private-headers-devel >= %{real_version}
%if %{qt5_snapshot}
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(Qt5Qml) >= %{real_version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{real_version}
%requires_ge    libQt5Widgets5
%requires_ge    libQtQuick5

%description
The Qt Quick Controls2 module provides a set of controls that
can be used to build complete interfaces in Qt Quick.

%package -n libQt5QuickControls2-5
Summary:        Qt 5 QuickControl2 Library
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          System/Libraries

%description -n libQt5QuickControls2-5
Qt is a set of libraries for developing applications.

This package contains base tools, like string, xml, and network
handling.

%package -n libQt5QuickTemplates2-5
Summary:        Qt5 QuickTemplates2 Library
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          System/Libraries

%description -n libQt5QuickTemplates2-5
You need this package if you want to compile programs with qtquickcontrols2.

%package -n libQt5QuickControls2-devel
Summary:        Qt Development Kit
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
Requires:       libQt5QuickControls2-5 = %{version}

%description -n libQt5QuickControls2-devel
You need this package if you want to compile programs with qtquickcontrols2.

%package -n libQt5QuickTemplates2-devel
Summary:        Qt Development Kit
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
Requires:       libQt5QuickTemplates2-5 = %{version}

%description -n libQt5QuickTemplates2-devel
You need this package if you want to compile programs with qtquickcontrols2.

%package private-headers-devel
Summary:        Headers for the unstable API of the Qt5 QuickControls2 module
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
Requires:       libQt5QuickControls2-devel = %{version}
Requires:       libQt5QuickTemplates2-devel = %{version}

%description private-headers-devel
You need this package if you want to compile programs against the unstable API
of the Qt5 QuickControls 2 module.

%package examples
Summary:        Qt5 quickcontrols2 examples
License:        BSD-3-Clause
Group:          Development/Libraries/X11

%description examples
Examples for libqt5-qtquickcontrols2 module.

%prep
%autosetup -n %{tar_version}

%build
%if %{qt5_snapshot}
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%qmake5
%make_jobs

%install
%qmake5_install
find %{buildroot}/%{_libqt5_libdir} -type f -name '*la' -print -exec perl -pi -e 's,-L%{_builddir}/\S+,,g' {} +
find %{buildroot}/%{_libqt5_libdir} -type f -name '*pc' -print -exec perl -pi -e "s, -L$RPM_BUILD_DIR/?\S+,,g" {} + -exec sed -i -e "s,^moc_location=.*,moc_location=%{_lib}qt5_bindir/moc," -e "s,uic_location=.*,uic_location=%{_lib}qt5_bindir/uic," {} +
find %{buildroot}/%{_libqt5_libdir} -type f -name '*prl' -exec sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" {} +

# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

%post -n libQt5QuickControls2-5 -p /sbin/ldconfig
%postun -n libQt5QuickControls2-5 -p /sbin/ldconfig
%post -n libQt5QuickTemplates2-5 -p /sbin/ldconfig
%postun -n libQt5QuickTemplates2-5 -p /sbin/ldconfig

%files -n libQt5QuickControls2-5
%license LICENSE.*
%{_libqt5_libdir}/libQt5QuickControls2.so.*

%files -n libQt5QuickTemplates2-5
%license LICENSE.*
%{_libqt5_libdir}/libQt5QuickTemplates2.so.*

%files
%license LICENSE.*
%{_libqt5_archdatadir}/qml/QtQuick
%{_libqt5_archdatadir}/qml/Qt

%files -n libQt5QuickControls2-devel
%license LICENSE.*
%exclude %{_libqt5_includedir}/QtQuickControls2/%{so_version}
%{_libqt5_includedir}/QtQuickControls2
%{_libqt5_libdir}/cmake/Qt5QuickControls2
%{_libqt5_libdir}/libQt5QuickControls2.prl
%{_libqt5_libdir}/libQt5QuickControls2.so
%{_libqt5_libdir}/pkgconfig/Qt5QuickControls2.pc
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_quickcontrols2.pri

%files -n libQt5QuickTemplates2-devel
%license LICENSE.*
%exclude %{_libqt5_includedir}/QtQuickTemplates2/%{so_version}
%{_libqt5_includedir}/QtQuickTemplates2
%{_libqt5_libdir}/cmake/Qt5QuickTemplates2
%{_libqt5_libdir}/libQt5QuickTemplates2.prl
%{_libqt5_libdir}/libQt5QuickTemplates2.so
%{_libqt5_libdir}/pkgconfig/Qt5QuickTemplates2.pc
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_quicktemplates2.pri

%files private-headers-devel
%license LICENSE.*
%{_libqt5_includedir}/QtQuickControls2/%{so_version}
%{_libqt5_includedir}/QtQuickTemplates2/%{so_version}
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_quickcontrols2_private.pri
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_quicktemplates2_private.pri

%files examples
%license LICENSE.*
%{_libqt5_examplesdir}/

%changelog
* Mon Nov 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.16+kde5, rebased upstream:
  * Don't leak buttons in QQuickDialogButtonBox
  * Fix connection leak in header proxy model
  * Bump version to 5.15.16
* Wed Sep  4 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.15+kde5, rebased upstream:
  * Bump version to 5.15.15
  * RangeSlider: Don't update position only if mouse/touch is grabbed
* Wed May 29 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.14+kde5, rebased upstream:
  * Bump version to 5.15.14
* Tue Mar 19 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.13+kde5, rebased upstream:
  * Bump version to 5.15.13
* Fri Dec 29 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.12+kde5, rebased upstream:
  * Bump version to 5.15.12
* Fri Oct  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.11+kde5, rebased upstream:
  * Take over touch grab after initial delayed mouse press from Flickable
  * Doc: Fix link to Scrollbar size property
* Tue Jun 13 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.10+kde6, rebased upstream:
  * Accessibility: respect value in attached Accessible in controls
  * TextArea: make clip node wider to accommodate cursor when right-aligned
  * DialogButtonBox: fix buttons going outside box on size change
  * Control in pressDelay Flickable: detect touch release near press pos
  * Reset provider's texture if QQuickNiniPatchImage's source is invalid
  * FileDialog: do not add default suffix when content scheme is used
* Fri Apr 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde11, rebased upstream:
  * SwipeView: don't cull every child item that gets added
  * AbstractButton: fix fast clicks being treated as double clicks
* Mon Jan  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde7, rebased upstream:
  * RangeSlider: update handle positions when 'from' or 'to' value is changed
  * Fix build without accessibility
  * Register the overlay with QQuickApplicationWindow
  * Consider all popups in the stack to test whether an event should be blocked
  * Give focus to popup on prepareEnter instead of finalizeEnter
  * Fix activeFocus for highest-z popup
* Thu Dec 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.7+kde7:
  * Fix the popup position of a Menu
* Thu Nov  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.7+kde6, rebased upstream:
  * implement a11y pressing of qquickabstractbutton
  * Blacklist some flaky tst_qquickpopup functions on openSUSE
  * Fix memory leak in Qt Quick Controls icon
* Mon Sep 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.6+kde5, rebased upstream:
  * Revert "ToolTip: use contentWidth of Text contentItem to account for newlines"
  * Doc: make it clear that Page doesn't render its title text
  * QQuickComboBox: fix acceptableInput being wrong if no validator was set
  * Add recursion guard to QQuickApplicationWindowPrivate::relayout()
  * Fix SwipeDelegate losing swipes to parent flickables
  * Blacklist some flaky tst_qquickdrawer functions on openSUSE
  * Fix warnings in some tests
  * ToolTip: use contentWidth of Text contentItem to account for newlines
* Wed Aug 24 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.5+kde6:
  * Fix scroll bars not showing up when binding to standalone contentItem
* Mon Jun 27 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.5+kde5, rebased upstream:
  * Revert "Allow creation of custom QQuickPopupItem-derived types"
  * QQuickAbstractButton: fix crash on destruction
  * TextArea: Detach the flickable when it is deleted
  * Don't call QQml_setParent_noEvent with a nullptr item
  * Hide old scroll bars
  * Allow creation of custom QQuickPopupItem-derived types
  * Imagine: fix GroupBox's bottom edge being clipped
  * QQuickDial: Keep value integer if everything is integer
  * ScrollView: fix crash when scrolling with zero-sized item
  * Change the name of the material style plugin to avoid a path limit
  * QmlDesigner: Fix RangeSliderSpecifics snap mode
  * Ensure the ninepatch image is detached
  * Ninepatch: keep resetNode status to not lose track of ImageNode->NinePatchNode changes
  * Revert "Update commercial license headers"
  * Fix static build
  * ComboBox: don't focus TextField when clicking on indicator
  * Combobox: Fix initial set of inputMethodHints
  * Fix popups with exit transitions blocking mouse events when destroyed
  * a11y: Fix ordering on header, content item and footer in Page
  * Update commercial license headers
  * Fix initial currentIndex in Tumbler when wrap is set to false
  * SwipeDelegate: ensure background and contentItem are resized
  * Reset the opacity and scale properties after the exit transition
- Drop 0001-Revert-Bump-version.patch, it's versioned correctly now
* Fri Jan 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde10:
  * QQuickAction: don't grab the same shortcut multiple times
  * Ensure we don't crash when changing sizes after cleanup
* Thu Oct 28 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde8:
  * Unset mouseGrabberPopup if it's removed from children
* Tue Jun 22 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde7:
  * QmlDesigner: Remove duplicate of repeat
  * Doc: remove all instances of \qmlpropertygroup
  * Doc: fix Qt Labs Platform Menu icon documentation
  * Fix QQuickHeaderView models to pass model tester
  * Doc: fix SplitView's inheritance
  * Add changes file for Qt 5.15.2
  * Bump version
- Add patch to reset version to 5.15.2:
  * 0001-Revert-Bump-version.patch
* Sat Jan 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add compatibility with qml-autoreqprov
* Fri Nov 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.15.2/?h=5.15.2
* Thu Sep 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.15.1/?h=5.15.1
* Tue May 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0:
  * No changelog available
* Wed May 20 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0-rc2:
  * No changelog available
* Wed May  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.15.0/?h=5.15.0
* Fri Apr 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
* Tue Apr 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
* Tue Mar 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 19 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-alpha:
  * New feature release
  * For more details please see:
    https://wiki.qt.io/New_Features_in_Qt_5.15
* Mon Jan 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.14.1/?h=v5.14.1
* Tue Dec 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update the license tags.
* Thu Dec 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0:
  * New bugfix release
  * For the changes between 5.13.2 and 5.14.0 please see:
    https://code.qt.io/cgit/qt/qtquickcontrols2.git/tree/dist/changes-5.14.0?h=v5.14.0
  * For the changes between 5.13.1 and 5.13.2 please see:
    https://code.qt.io/cgit/qt/qtquickcontrols2.git/tree/dist/changes-5.13.2?h=v5.14.0
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-rc:
  * New bugfix release
  * No changelog available
  * For more details please see:
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta3:
  * New bugfix release
  * No changelog available
* Thu Oct 24 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta2:
  * New bugfix release
  * No changelog available
* Tue Oct 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta1:
  * New bugfix release
  * No changelog available
* Mon Sep 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-alpha:
  * New feature release
  * No changelog available
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Fri Sep  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.13.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.13.1/?h=v5.13.1
* Wed Jun 19 2019 fabian@ritter-vogt.de
- Update to 5.13.0:
  * New bugfix release
  * No changelog available
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.13.0/?h=5.13
* Tue Jun  4 2019 fabian@ritter-vogt.de
- Update to 5.13.0-rc:
  * New bugfix release
  * No changelog available
* Mon Apr 29 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta2:
  * New bugfix release
  * No changelog available
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Fri Mar 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add private-headers-devel subpackage - those were not packaged at all before
* Thu Mar 21 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta1:
  * New feature release
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.13.0/?h=5.13
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.12.2/?h=5.12.2
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.12.1/?h=v5.12.1
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.12.0/?h=5.12.0
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.11.0/?h=v5.11.0
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtquickcontrols2.git/plain/dist/changes-5.10.1/?h=v5.10.1
* Fri Dec  8 2017 christophe@krop.fr
- Update the license tag (boo#967696)
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtquickcontrols2.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1:
  * Introduced new QML types: Action, ActionGroup, MenuBar
  * Introduced new styles:
    + the Fusion style offers a platform agnostic desktop-oriented look'n'feel
    + the Imagine style is based on image assets that can be provided using a predefined naming convention
  * Other stuff, too long to fit here
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
* Sun Sep 25 2016 jengelh@inai.de
- Set proper RPM groups for SLPP packages. Use faster {} +
  find syntax.
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.qt.io/qt5-7/
* Sat Jul 16 2016 hrvoje.senjan@gmail.com
- Activate libqt5-qtquickcontrols2 package
